use serde::Deserialize;

#[derive(Deserialize)]
pub struct SubscribeDto { 
    pub public_key: String,
    pub password: String
}
